from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Int, File, Boolean

Anvi_Setup_Ncbi_Cogs_V0_1_0 = CommandToolBuilder(tool="anvi_setup_ncbi_cogs", base_command=["anvi-setup-ncbi-cogs"], inputs=[ToolInput(tag="in_cog_version", input_type=Int(optional=True), prefix="--cog-version", doc=InputDocumentation(doc="COG version. The default is the latest version, which\nis COG20, meaning that anvi'o will use the NCBI's 2020\nrelease of COGs to setup the database and run it on\ncontigs databases. There is also an older version of\nCOGs from 2014. If you would like anvi'o to work with\nthat one, please use COG14 as a parameter. On a single\ncomputer you can have both, and on a single contigs\ndatabase you can run both. Cool and confusing. The\nanvi'o way. (default: None)")), ToolInput(tag="in_cog_data_dir", input_type=File(optional=True), prefix="--cog-data-dir", doc=InputDocumentation(doc="The directory for COG data to be stored. If you leave\nit as is without specifying anything, the default\ndestination for the data directory will be used to set\nthings up. The advantage of it is that everyone will\nbe using a single data directory, but then you may\nneed superuser privileges to do it. Using this\nparameter you can choose the location of the data\ndirectory somewhere you like. However, when it is time\nto run COGs, you will need to remember that path and\nprovide it to the program. (default: None)")), ToolInput(tag="in_reset", input_type=Boolean(optional=True), prefix="--reset", doc=InputDocumentation(doc="Remove all the previously stored files and start over.\nIf something is feels wrong for some reason and if you\nbelieve re-downloading files and setting them up could\naddress the issue, this is the flag that will tell\nanvi'o to act like a real computer scientist\nchallenged with a computational problem. (default:\nFalse)")), ToolInput(tag="in_just_do_it", input_type=Boolean(optional=True), prefix="--just-do-it", doc=InputDocumentation(doc="Don't bother me with questions or warnings, just do\nit. (default: False)")), ToolInput(tag="in_num_threads", input_type=Int(optional=True), prefix="--num-threads", doc=InputDocumentation(doc="Maximum number of threads to use for multithreading\nwhenever possible. Very conservatively, the default is\n1. It is a good idea to not exceed the number of CPUs\n/ cores on your system. Plus, please be careful with\nthis option if you are running your commands on a SGE\n--if you are clusterizing your runs, and asking for\nmultiple threads to use, you may deplete your\nresources very fast. (default: 1)"))], outputs=[], container="quay.io/biocontainers/anvio-minimal:7--py_0", version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Anvi_Setup_Ncbi_Cogs_V0_1_0().translate("wdl")

